{% extends "sentry/layout.html" %}

{% load i18n %}

{% block title %}{% trans "Forbidden" %} | {{ block.super }}{% endblock %}

{% block page_header %}
    <h2>{% trans "Forbidden" %}</h2>
{% endblock %}

{% block content %}
    <section class="body">
        <p>{% trans "You do not have access to this page with your current permissions." %}</p>
    </section>
{% endblock %}
