{% extends "sentry/layout.html" %}

{% load i18n %}
{% load sentry_helpers %}
{% load static_compiler %}

{% block css %}
    {% staticbundle 'sentry/styles/wall.min.css' %}
{% endblock %}

{% block body %}
    <div class="container-fluid" id="stats" data-uri="{% url 'sentry-api-stats' team.slug %}?minutes=1440">
        <div class="row-fluid">
            <div class="span4" data-stat="events">
                <big><span>???</span></big>
                <label><strong>Events</strong> in the last 24 hours</label>
            </div>
            <div class="span4" data-stat="resolved">
                <big><span>???</span></big>
                <label><strong>Resolved</strong> in the last 24 hours</label>
            </div>
        </div>
    </div>
    <div class="container-fluid" id="chart">
        <div class="row-fluid">
            <div class="chart" data-api-url="{% url 'sentry-api-chart' team.slug %}">
                <span class="loading">{% trans "Loading historical data..." %}</span>
            </div>
        </div>
    </div>
    <div class="container-fluid" id="events">
        <div class="row-fluid">
            <div class="span6">
                <ul class="nav nav-labels">
                    <li class="active"><a href="#trending" data-toggle="ajtab" data-uri="{% url 'sentry-api-groups-trends' team.slug %}?minutes=1440&amp;limit=5">{% trans "Trending" %}</a></li>
                </ul>
                <div class="tab-content">
                    <div class="tab-pane active" id="trending"><p>Loading ...</p></div>
                </div>
            </div>
            <div class="span6">
                <ul class="nav nav-labels">
                    <li class="active"><a href="#new" data-toggle="ajtab" data-uri="{% url 'sentry-api-groups-new' team.slug %}?minutes=1440&amp;limit=5">{% trans "New" %}</a></li>
                </ul>
                <div class="tab-content">
                    <div class="tab-pane active" id="new"><p>Loading ...</p></div>
                </div>
            </div>
        </div>
    </div>

    <script>
    $(function(){
        new app.WallPage();
    });
    </script>
{% endblock %}
