{% extends "sentry/layout.html" %}

{% load i18n %}

{% block title %}{% trans "Team Invite" %} | {{ block.super }}{% endblock %}

{% block page_header_block %}{% endblock %}
{% block bodyclass %}{% endblock %}

{% block main %}
    <section class="body">
        <div class="row">
            <div class="span7">
                <div class="page-header">
                    <h2>{% trans "Team Invite" %}</h2>
                </div>

                <p style="font-size: 1.3em;">{% blocktrans with team_name=team.name %}<strong>{{ team_owner }}</strong> is using Sentry to aggregate errors for the <strong>{{ team_name }}</strong> team.{% endblocktrans %}</p>

                <p>{% blocktrans with project_count=project_list|length %}You have been invited to join this team, which manages <strong>{{ project_count }}</strong> project(s):{% endblocktrans %}</p>
                <ul>
                    {% for project in project_list|slice:"5" %}
                        <li>
                            {{ project.name }}
                        </li>
                    {% endfor %}
                </ul>
                    {% csrf_token %}
            
                    <p>{% trans "To continue, you must either login to your existing account, or create a new one." %}</p>

                    <fieldset class="form-actions">
                        <div class="pull-right" style="margin-top: 5px;">
                            <a href="{% url 'sentry-login' %}">{% trans "Login as an existing user" %}</a>
                        </div>
                        <a href="{% url 'sentry-register' %}" class="btn btn-primary">{% trans "Create a new account" %}</a>
                    </fieldset>
                </form>
            </div>
        </div>
    </section>
{% endblock %}
