{% extends "sentry/emails/base.html" %}

{% load i18n %}

{% block header %}
    <h1>Sentry <small>New Alert</small></h1>
{% endblock %}

{% block inner %}
    <pre>{{ alert.message }}</pre>

    <p><a href="{{ link }}">{{ link }}</a></p>

    <table class="metadata">
        <colgroup>
            <col style="width:25%;">
            <col style="width:25%;">
            <col style="width:25%;">
            <col style="width:25%;">
        </colgroup>
        <tr>
            <th>{% trans "Datetime:" %}</th>
            <td>{{ alert.datetime }}</td>
            <th>{% trans "Project:" %}</th>
            <td>{{ alert.project.name }}</td>
        </tr>
    </table>

    <p><a href="{{ settings_link }}">Notification Settings</a></p>
{% endblock %}
