<span class="github" data-user="{{ user }}" data-repo="{{ repo }}">
	<span id="github-btn" class="github-btn">
		<a id="gh-btn" href="https://github.com/{{ user }}/{{ repo }}" target="_blank" class="gh-btn">
			<span class="gh-ico"></span>
			<span id="gh-text" class="gh-text">{{ repo }}</span>
		</a>
	</span>
</span>