{% extends "sentry/teams/members/index.html" %}

{% load i18n %}

{% block title %}{% trans "New Member" %} | {{ block.super }}{% endblock %}

{% block sidebar %}
    {{ block.super }}
    <h6>{% trans "Access Levels" %}</h6>
    <p>{% blocktrans %}The primary difference between access levels is team management. Any member with admin access is treated almost identical to the team owner.{% endblocktrans %}</p>
{% endblock %}

{% block inner %}
    <ul class="nav nav-tabs">
        <li class="active"><a href="#invite" data-toggle="tab">{% trans "Invite a new user" %}</a></li>
        <li><a href="#add" data-toggle="tab">{% trans "Add an existing user" %}</a></li>
    </ul>
    <div class="tab-content">
        <div class="tab-pane active" id="invite">
            <p>{% trans "Invite a member to join this team via their email address. If they do not already have an account they will first be asked to create one." %}</p>
            {% with invite_form as form %}
                {% include "sentry/partial/_form.html" %}
            {% endwith %}
        </div>
        <div class="tab-pane" id="add">
            <p>{% trans "You may add a user by their username if they already have an account." %}</p>
            {% with add_form as form %}
                {% include "sentry/partial/_form.html" %}
            {% endwith %}
        </div>
    </div>

    <script type="text/javascript">
    new app.AddTeamMemberPage();
    </script>
{% endblock %}
