{% extends "sentry/projects/manage.html" %}

{% load i18n %}
{% load sentry_helpers %}

{% block title %}{% trans "Client Configuration" %} | {{ block.super }}{% endblock %}

{% block inner %}
    <div class="page-header">
        <h2>{% trans "Client Configuration" %}</h2>
    </div>
    {% client_help request.user project %}
{% endblock %}

