{% extends "sentry/layout.html" %}

{% load i18n %}

{% block title %}{% trans "Internal Server Error" %} | {{ block.super }}{% endblock %}

{% block page_header_block %}{% endblock %}
{% block bodyclass %}{% endblock %}

{% block main %}
    <section class="body">
        <div class="page-header">
            <h2>{% trans "Internal Server Error" %}</h2>
        </div>
        <p>{% trans "There was an internal server error while processing your request." %}</p>
        {% if request.sentry.id %}
            <p>{% blocktrans with request.sentry.id as id %}You may reference this error as <strong>{{ id }}</strong>.{% endblocktrans %}</p>
        {% endif %}
    </section>
{% endblock %}
