.select2-container,
.select2-drop,
.select2-search,
.select2-search input{
  /*
    Force border-box so that % widths fit the parent
    container without overlap because of margin/padding.

    More Info : http://www.quirksmode.org/css/box.html
  */
  -moz-box-sizing: border-box;    /* firefox */
  -ms-box-sizing: border-box;     /* ie */
  -webkit-box-sizing: border-box; /* webkit */
  -khtml-box-sizing: border-box;  /* konqueror */
  box-sizing: border-box;         /* css3 */
}

.select2-container {
  position: relative;
  display: inline-block;
  /* inline-block for ie7 */
  zoom: 1;
  *display: inline;
  vertical-align: middle;

  .select2-choice {
    .border-radius(3px);
    .box-shadow(0 2px 0 rgba(205, 216, 227, .32));
    .background-clip(padding-box);
    -moz-background-clip: padding;
    background-color: #fff;
    display: block;
    overflow: hidden;
    white-space: nowrap;
    position: relative;
    height: 32px;
    line-height: 32px;
    padding: 0 0 0 14px;
    color: #757f87;
    text-decoration: none;
    font-weight: bold;

    &:hover {
      color: #7d858d !important;
    }

    span {
      margin-right: 46px;
      display: block;
      .text-overflow();
    }

    abbr {
      display: block;
      position: absolute;
      right: 27px;
      top: 12px;
      width: 12px;
      height: 12px;
      font-size: 1px;
      background: url('../scripts/lib/select2/select2.png') right top no-repeat;
      cursor: pointer;
      text-decoration: none;
      border:0;
      outline: 0;

      &:hover {
        background-position: right -11px;
        cursor: pointer;
      }
    }

    div {
      -moz-background-clip: padding;
      -webkit-background-clip: padding-box;
      background-clip: padding-box;
      position: absolute;
      right: 5px;
      top: 5px;
      display: block;
      height: 100%;
      width: 18px;

      b {
        background: url('../scripts/lib/select2/select2.png') no-repeat 0 1px;
        display: block;
        width: 100%;
        height: 100%;
      }
    }
  }
}

.select2-container.select2-drop-above .select2-choice {
    .border-radius(0px 0px 3px 3px);
}

.select2-drop {
  background: #fff;
  color: #000;
  border-top: 0;
  position: absolute;
  top: 100%;
  z-index: 9999;
  width:100%;
  padding-top: 0;
  .box-shadow(0 0 0 2px #a7aeb7);
  .border-radius(0 0 3px 3px);

  &:after {
    display: block;
    content: "";
    height: 4px;
    background: #fff;
    position: absolute;
    top: -4px;
    left: 0;
    right: 0;
  }
}

.select2-drop.select2-drop-above {
  .border-radius(4px 4px 0px 0px);
  .box-shadow(0 0 0 2px #a7aeb7);
  border-bottom: 0;

  &:after {
    top: auto;
    bottom: -4px;
  }
}

.select2-search {
  display: inline-block;
  white-space: nowrap;
  z-index: 10000;
  min-height: 26px;
  width: 100%;
  margin: 0;
  padding-left: 4px;
  padding-right: 4px;

  input {
    background: #fff url('../scripts/lib/select2/select2.png') no-repeat 99% -22px;
    background: url('../scripts/lib/select2/select2.png') no-repeat 99% -22px, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #fff), color-stop(0.99, #eee));
    background: url('../scripts/lib/select2/select2.png') no-repeat 99% -22px, -webkit-linear-gradient(center bottom, #fff 85%, #eee 99%);
    background: url('../scripts/lib/select2/select2.png') no-repeat 99% -22px, -moz-linear-gradient(center bottom, #fff 85%, #eee 99%);
    background: url('../scripts/lib/select2/select2.png') no-repeat 99% -22px, -o-linear-gradient(bottom, #fff 85%, #eee 99%);
    background: url('../scripts/lib/select2/select2.png') no-repeat 99% -22px, -ms-linear-gradient(top, #fff 85%, #eee 99%);
    background: url('../scripts/lib/select2/select2.png') no-repeat 99% -22px, linear-gradient(top, #fff 85%, #eee 99%);
    padding: 4px 26px 4px 6px;
    outline: 0;
    border: 1px solid #aaa;
    font-family: sans-serif;
    font-size: 1em;
    width: 100%;
    margin: 0;
    height:auto !important;
    min-height: 26px;
    .box-shadow(none);
    .border-radius(2px);
  }
}

.select2-search-hidden {
  display: block;
  position: absolute;
  left: -10000px;
}

.select2-drop.select2-drop-above .select2-search input{
    margin-top:4px;
}

.select2-search input.select2-active {
    background: #fff url('../scripts/lib/select2/spinner.gif') no-repeat 100%;
    background: url('../scripts/lib/select2/spinner.gif') no-repeat 100%, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, white), color-stop(0.99, #eeeeee));
    background: url('../scripts/lib/select2/spinner.gif') no-repeat 100%, -webkit-linear-gradient(center bottom, white 85%, #eeeeee 99%);
    background: url('../scripts/lib/select2/spinner.gif') no-repeat 100%, -moz-linear-gradient(center bottom, white 85%, #eeeeee 99%);
    background: url('../scripts/lib/select2/spinner.gif') no-repeat 100%, -o-linear-gradient(bottom, white 85%, #eeeeee 99%);
    background: url('../scripts/lib/select2/spinner.gif') no-repeat 100%, -ms-linear-gradient(top, #ffffff 85%, #eeeeee 99%);
    background: url('../scripts/lib/select2/spinner.gif') no-repeat 100%, linear-gradient(top, #ffffff 85%, #eeeeee 99%);
}

.select2-container-active .select2-choice,
.select2-container-active .select2-choices {
    outline: none;
}

.select2-dropdown-open .select2-choice {
  .box-shadow(0 0 0 2px #a7aeb7);

  -webkit-border-bottom-left-radius : 0;
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-bottomleft : 0;
  -moz-border-radius-bottomright: 0;
  border-bottom-left-radius : 0;
  border-bottom-right-radius: 0;
}

.select2-dropdown-open .select2-choice div {
  background: transparent;
  border-left: none;
}
.select2-dropdown-open .select2-choice div b {
  background-position: -18px 1px;
}

/* results */
.select2-results {
  margin: 4px 4px 4px 0;
  padding: 0 0 0 4px;
  position: relative;
  overflow-x: hidden;
  overflow-y: auto;
  max-height: 200px;

  ul.select2-result-sub {
    margin: 0;
  }
}

.select2-results ul.select2-result-sub > li .select2-result-label { padding-left: 20px }
.select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 40px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 60px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 80px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 100px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 110px }
.select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label { padding-left: 120px }

.select2-results li {
  list-style: none;
  display: list-item;
}

.select2-results li.select2-result-with-children > .select2-result-label {
  font-weight: bold;
}

.select2-results .select2-result-label {
  padding: 3px 7px 4px;
  margin: 0;
  cursor: pointer;
}

.select2-results .select2-highlighted {
  background: #2fb5f8;
  color: #fff;
  .border-radius(2px);
}
.select2-results li em {
  background: #feffde;
  font-style: normal;
}
.select2-results .select2-highlighted em {
  background: transparent;
}
.select2-results .select2-no-results,
.select2-results .select2-searching,
.select2-results .select2-selection-limit {
  padding: 3px 7px 4px;
  display: list-item;
  color: #7d858d;
  text-align: center;
}

/*
disabled look for already selected choices in the results dropdown
.select2-results .select2-disabled.select2-highlighted {
    color: #666;
    background: #f4f4f4;
    display: list-item;
    cursor: default;
}
.select2-results .select2-disabled {
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
*/
.select2-results .select2-disabled {
    display: none;
}

.select2-more-results.select2-active {
    background: #f4f4f4 url('spinner.gif') no-repeat 100%;
}

.select2-more-results {
  background: #f4f4f4;
  display: list-item;
}

/* disabled styles */

.select2-container.select2-container-disabled .select2-choice {
    background-color: #f4f4f4;
    background-image: none;
    border: 1px solid #ddd;
    cursor: default;
}

.select2-container.select2-container-disabled .select2-choice div {
    background-color: #f4f4f4;
    background-image: none;
    border-left: 0;
}


/* multiselect */

.select2-container-multi .select2-choices {
  background-color: #fff;
  background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, color-stop(1%, #eeeeee), color-stop(15%, #ffffff));
  background-image: -webkit-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  background-image: -moz-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  background-image: -o-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  background-image: -ms-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  background-image: linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  border: 1px solid #aaa;
  margin: 0;
  padding: 0;
  cursor: text;
  overflow: hidden;
  height: auto !important;
  height: 1%;
  position: relative;
}

.select2-container-multi .select2-choices {
    min-height: 26px;
}

.select2-container-multi.select2-container-active .select2-choices {
    .box-shadow(0 0 5px rgba(0,0,0,.3));
    border: 1px solid #5897fb;
    outline: none;
}
.select2-container-multi .select2-choices li {
  float: left;
  list-style: none;
}
.select2-container-multi .select2-choices .select2-search-field {
  white-space: nowrap;
  margin: 0;
  padding: 0;
}

.select2-container-multi .select2-choices .select2-search-field input {
  color: #666;
  background: transparent !important;
  font-family: sans-serif;
  font-size: 100%;
  height: 15px;
  padding: 5px;
  margin: 1px 0;
  outline: 0;
  border: 0;
  .box-shadow(none);
}

.select2-container-multi .select2-choices .select2-search-field input.select2-active {
    background: #fff url('../scripts/lib/select2/spinner.gif') no-repeat 100% !important;
}

.select2-default {
  color: #a6afb6 !important;
}

.select2-container-multi .select2-choices .select2-search-choice {
  .border-radius(3px);
  -moz-background-clip   : padding;
  -webkit-background-clip: padding-box;
  background-clip        : padding-box;
  background-color: #e4e4e4;
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f4f4f4', endColorstr='#eeeeee', GradientType=0 );
  background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, color-stop(20%, #f4f4f4), color-stop(50%, #f0f0f0), color-stop(52%, #e8e8e8), color-stop(100%, #eeeeee));
  background-image: -webkit-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  background-image: -moz-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  background-image: -o-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  background-image: -ms-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  background-image: linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  -webkit-box-shadow: 0 0 2px #ffffff inset, 0 1px 0 rgba(0,0,0,0.05);
  -moz-box-shadow   : 0 0 2px #ffffff inset, 0 1px 0 rgba(0,0,0,0.05);
  box-shadow        : 0 0 2px #ffffff inset, 0 1px 0 rgba(0,0,0,0.05);
  color: #333;
  border: 1px solid #aaaaaa;
  line-height: 13px;
  padding: 3px 5px 3px 18px;
  margin: 3px 0 3px 5px;
  position: relative;
  cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice span {
  cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice-focus {
  background: #d4d4d4;
}

.select2-search-choice-close {
  display: block;
  position: absolute;
  right: -35px;
  top: 4px;
  width: 12px;
  height: 13px;
  font-size: 1px;
  background: url('../scripts/lib/select2/select2.png') right top no-repeat;
  outline: none;
}

.select2-container-multi .select2-search-choice-close {
  left: 3px;
}


.select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close:hover {
  background-position: right -11px;
}
.select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close {
  background-position: right -11px;
}

/* disabled styles */

.select2-container-multi.select2-container-disabled .select2-choices{
    background-color: #f4f4f4;
    background-image: none;
    border: 1px solid #ddd;
    cursor: default;
}

.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice {
    background-image: none;
    background-color: #f4f4f4;
    border: 1px solid #ddd;
    padding: 3px 5px 3px 5px;
}

.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close {
    display: none;
}
/* end multiselect */

.select2-result-selectable .select2-match,
.select2-result-unselectable .select2-result-selectable .select2-match { text-decoration: underline; }
.select2-result-unselectable .select2-match { text-decoration: none; }

.select2-offscreen { position: absolute; left: -10000px; }

/* Retina-ize icons */

@media only screen and (-webkit-min-device-pixel-ratio: 1.5) {
  .select2-search input, .select2-search-choice-close, .select2-container .select2-choice abbr {
		background-image: url(../scripts/lib/select2/select2x2.png) !important;
		background-repeat: no-repeat !important;
		background-size: 60px 40px !important;
	}
	.select2-search input {
		background-position: 100% -21px !important;
	}
}
