{% extends "sentry/layout.html" %}

{% load i18n %}
{% load sentry_helpers %}

{% block title %}{% trans "Alerts" %} | {{ project.name }} | {{ block.super }}{% endblock %}

{% block bodyclass %}{% endblock %}

{% block main %}
    <section class="body">
        <div class="page-header">
            <h2>{% trans "Recent Alerts" %}</h2>
        </div>
        <ul>
            {% for alert in alert_list %}
                <li>
                    <h4><a href="{% url 'sentry-alert-details' project.team.slug project.slug alert.id %}">{{ alert.datetime }}</a>
                        <small>
                            &mdash; <span class="pretty-date" title="{{ alert.datetime|date:"c" }}Z">{{ alert.datetime|timesince }}</span>
                        </small></h4>
                    {{ alert.message|linebreaks }}
                </li>
            {% endfor %}
        </ul>
        <p>You can change your alert settings by visiting your <a href="{% url 'sentry-project-notifications' project.team.slug project.slug %}">project's notification settings</a> page.</p>
    </section>
{% endblock %}
