{% extends "sentry/partial/client_config/java_base.html" %}

{% load i18n %}

{% block inner %}
    <p>{% trans "You'll need to configure the SentryAppender in your logging configuration:" %}</p>

    <pre>&lt;configuration&gt;
    &lt;appender name="Sentry" class="net.kencochrane.raven.logback.SentryAppender"&gt;
        &lt;dsn&gt;
            {% if dsn %}{{ dsn }}{% else %}<strong>SENTRY_DSN</strong>{% endif %}
        &lt;/dsn&gt;
    &lt;/appender&gt;

    &lt;root level="error"&gt;
        &lt;appender-ref ref="Sentry"/&gt;
    &lt;/root&gt;
&lt;/configuration&gt;</pre>
{% endblock %}
