{% extends "sentry/groups/details.html" %}

{% load i18n %}

{% block title %}{{ title }} | {{ block.super }}{% endblock %}

{% block inner %}
    <div class="span12">
        <div class="page-header">
            <h3>{{ title }}</h3>
        </div>
        <div class="alert alert-block">
            {% url 'socialauth_associate_begin' plugin.auth_provider as link %}
            <p>{% blocktrans %}You still need to <a href="{{ link }}">associate an identity</a> with {{ title }} before you can
            create issues with this service.{% endblocktrans %}</p>
        </div>
    </div>
{% endblock %}
