{% load i18n %}
{% load sentry_helpers %}
{% load sentry_plugins %}

<div id="event_nav">
    <div class="event_nav_wrap">
        <ul class="nav nav-pills">
            {% with group|get_panels:request as panel_list %}
                {% if panel_list %}
                    <li class="dropdown pull-right">
                        <a href="javascript:void(0)" class="dropdown-toggle" data-toggle="dropdown">
                            <i class="icon-list"></i>
                        </a>
                        <ul class="dropdown-menu">
                            {% for label, link, is_active in panel_list %}
                                <li{% if is_active %} class="active"{% endif %}><a href="{{ link }}">{{ label }}</a></li>
                            {% endfor %}
                        </ul>
                    </li>
                {% endif %}
            {% endwith %}
            <li class="top{% if page == 'details' %} active{% endif %}">
                <a href="#" onclick="javascript:window.location = '#details'; return false">{% trans "Top" %}</a>
            </li>
            {% if tags %}
                <li>
                    <a href="#tags">{% trans "Tags" %}</a>
                </li>
            {% endif %}
            {% for interface, _ in interface_list %}
                <li>
                    <a href="#{{ interface.get_slug }}">
                        {{ interface.get_title }}
                    </a>
                </li>
            {% endfor %}
            {% if json_data %}
                <li>
                    <a href="#extra">{% trans "Additional Data" %}</a>
                </li>
            {% endif %}
            {% if version_data %}
                <li>
                    <a href="#versions">{% trans "Versions" %}</a>
                </li>
            {% endif %}
        </ul>
    </div>
</div>
