{% load i18n %}

<p>{% blocktrans with 'https://github.com/getsentry/raven-objc' as link %}Start by installing <a href="{{ link }}">raven-objc</a>:{% endblocktrans %}</p>

<pre>cd [your project root]
git submodule add git://github.com/getsentry/raven-objc</pre>

<p><small>{% trans "(Installing the client as a git submodule will make future updates easier)" %}</small></p>

<p>{% blocktrans %}Initialize the client. This is usually done in your app delegate's <code>application:didFinishLaunchingWithOptions</code>:{% endblocktrans %}</p>

<pre>- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    // Configure the Sentry client
    [RavenClient clientWithDSN:@"{% if dsn %}{{ dsn }}{% else %}<strong>SENTRY_DSN</strong>{% endif %}"];

    // Install the global error handler
    [[RavenClient sharedClient] setupExceptionHandler];

    return YES;
}
</pre>

<p>{% trans "That's it! Raven automatically installs an error handling hook to pipe all uncaught exceptions to Sentry." %}</p>

<p>{% blocktrans with 'https://github.com/getsentry/raven-objc' as link %}For more information on other uses of Raven with iOS, please see the <a href="{{ link }}">official documentation for raven-objc</a>.{% endblocktrans %}</p>
