.slider {
  width: 300px;
  padding-right: 100px;

  > .dragger {
    background: lighten(#4593DE, 5%);

    -webkit-box-shadow: inset 0 1px 1px rgba(255,255,255,0.5), 0 2px 8px rgba(0,0,0,0.2);
    -moz-box-shadow: inset 0 1px 1px rgba(255,255,255,0.5), 0 2px 8px rgba(0,0,0,0.2);
    box-shadow: inset 0 1px 1px rgba(255,255,255,0.5), 0 2px 8px rgba(0,0,0,0.2);

    -webkit-border-radius: 10px;
    -moz-border-radius: 10px;
    border-radius: 10px;

    border: 1px solid #4593DE;
    width: 16px;
    height: 15px;
  }

  > .dragger:hover {
    background: #4593DE;
  }

  > .track {
    background: #ccc;
    background: -webkit-linear-gradient(top, #bbb, #ddd);
    background: -moz-linear-gradient(top, #bbb, #ddd);
    background: linear-gradient(top, #bbb, #ddd);

    -webkit-box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);
    -moz-box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);
    box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);

    -webkit-border-radius: 8px;
    -moz-border-radius: 8px;
    border-radius: 8px;

    border: 1px solid #aaa;
    height: 3px;
  }

  > .value {
    top: -1px;
    position: absolute;
    right: -100px;
    width: 80px;
    color: #999;
  }
}
