"""
sentry.search.models
~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
:license: BSD, see LICENSE for more details.
"""

from __future__ import absolute_import

# HACK(dcramer): Django doesn't play well with our naming schemes, and we prefer
# our methods ways over Django's limited scoping
from .django.models import *  # NOQA
