{% load i18n %}
<div class="module">
    <div class="page-header">
        <h2>{% trans "Exception" %}</h2>
    </div>
    <div class="module-content">
        <table class="table table-striped">
            <colgroup>
                <col style="width:100px;">
            </colgroup>
            {% if exception_type %}
            <tr>
                <th>{% trans "Types:" %}</th>
                <td class="code"><pre>{{ exception_type|escape }}</pre></td>
            </tr>
            {% endif %}
            {% if exception_value %}
            <tr>
                <th>{% trans "Value:" %}</th>
                <td class="code"><pre>{{ exception_value|escape }}</pre></td>
            </tr>
            {% endif %}
            {% if last_frame %}
                <tr>
                    <th>{% trans "Location:" %}</th>
                    <td>{% if last_frame.filename %}{{ last_frame.filename|escape }}{% elif last_frame.module %}{{ last_frame.module|escape }}{% endif %}{% if last_frame.function %} in {{ last_frame.function|escape }} {% endif %}{% if last_frame.lineno %}, line {{ last_frame.lineno }}{% endif %}{% if last_frame.colno %} (col {{ last_frame.colno }}{% endif %}</td>
                </tr>
            {% endif %}
        </table>
    </div>
</div>
