{% extends "sentry/partial/client_config/ruby_base.html" %}

{% load i18n %}

{% block inner %}
	<p>{% trans "Create an instance of the client:" %}</p>

	<pre>require 'raven'

Raven.configure do |config|
  config.dsn = '{% if dsn %}{{ dsn }}{% else %}<strong>SENTRY_DSN</strong>{% endif %}'
end</pre>

	<p>{% trans "Now wrap your application to capture events:" %}</p>

	<pre>Raven.capture do
    MyApp.run
end</pre>

{% endblock %}