{% extends "sentry/layout.html" %}

{% load i18n %}

{% block title %}{{ project.name }} | {{ block.super }}{% endblock %}

{% block page_header %}
    {{ block.super }}
    <ul class="nav nav-tabs">
        <li>
            <a href="{% url 'sentry-stream' project.team.slug project.slug %}">{% trans "Stream" %}</a>
        </li>
        <li class="active">
            <a href="{% url 'sentry-stream' project.team.slug project.slug %}">{% trans "Explore" %}</a>
        </li>
        {% if can_admin_team %}
            <li>
                <a href="{% url 'sentry-manage-project' project.team.slug project.slug %}">{% trans "Settings" %}</a>
            </li>
        {% endif %}
    </ul>
{% endblock %}

{% block main %}
    <section class="body">
    	{% block inner %}{% endblock %}
    </section>
{% endblock %}
