{% extends "sentry/groups/details.html" %}

{% load i18n %}
{% load sentry_helpers %}

{% block inner %}
    {% paginate event_list from request as event_list per_page EVENTS_PER_PAGE %}

    {% if event_list.objects %}
        <p class="alert alert-info">{% blocktrans with 'http://sentry.readthedocs.org' as link %}This list only contains a portion of all events seen. For more information about how Sentry samples events, see the <a href="{{ link }}">documentation</a>.{% endblocktrans %}</p>

        {{ event_list.paging }}

        <ul class="events no-counts">
            {% for event in event_list.objects %}
                {% include "sentry/partial/_event.html" %}
            {% endfor %}
        </ul>

        {{ event_list.paging }}

    {% else %}
        <p class="alert alert-notice">{% trans "There are no records recorded for this event." %}</p>
    {% endif %}

{% endblock %}
