{% load i18n %}
{% load sentry_helpers %}

<div class="pull-right">
	{% github_button 'getsentry' 'raven-ruby' %}
</div>

<ul class="nav nav-tabs">
	<li{% if platform == 'ruby' %} class="active"{% endif %}><a href="{% url 'sentry-docs-client' project.team.slug project.slug 'ruby' %}">Ruby</a></li>
	<li{% if platform == 'rails3' %} class="active"{% endif %}><a href="{% url 'sentry-docs-client' project.team.slug project.slug 'rails3' %}">Rails 3</a></li>
  <li{% if platform == 'rails4' %} class="active"{% endif %}><a href="{% url 'sentry-docs-client' project.team.slug project.slug 'rails4' %}">Rails 4</a></li>
  <li{% if platform == 'sinatra' %} class="active"{% endif %}><a href="{% url 'sentry-docs-client' project.team.slug project.slug 'sinatra' %}">Sinatra</a></li>
  <li{% if platform == 'sidekiq' %} class="active"{% endif %}><a href="{% url 'sentry-docs-client' project.team.slug project.slug 'sidekiq' %}">Sidekiq</a></li>
</ul>


<p>{% blocktrans with 'https://github.com/getsentry/raven-ruby' as link %}Start by installing <a href="{{ link }}">raven-ruby</a>:{% endblocktrans %}</p>

<pre>gem install sentry-raven</pre>

<p>{% trans "Or add it to your <code>Gemfile</code>:" %}</p>

<pre>gem "sentry-raven", :git => "https://github.com/getsentry/raven-ruby.git"</pre>

{% block inner %}
{% endblock %}

<p>{% trans "You may want to give things a try, you might want to use the included Rake task to test your configuration:" %}</p>

<pre>rake raven:test</pre>

<p>{% trans "Note: If you're not bootstrapping the Raven gem somewhere that's included in your Rakefile, you'll have to manually pass the DSN value:" %}</p>

<pre>rake raven:test[DSN]</pre>

<p>{% blocktrans with 'https://github.com/getsentry/raven-ruby' as link %}For more information on other uses of Raven with Ruby, please see the <a href="{{ link }}">official documentation for raven-ruby</a>.{% endblocktrans %}</p>
