.github-btn {
    height: 20px;
    overflow: hidden;
    font: bold 11px/14px "Helvetica Neue", Helvetica, Arial, sans-serif;
    text-rendering: optimizeLegibility;
}
.gh-btn,
.gh-count,
.gh-ico {
    float: left;
}
.gh-btn,
.gh-count {
    padding: 2px 5px 2px 4px;
    color: #666;
    text-decoration: none;
    text-shadow: 0 1px 0 #fff;
    white-space: nowrap;
    cursor: pointer;
    .border-radius(3px);
}
.gh-btn {
    background-color: #e6e6e6;
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), color-stop(25%, #ffffff), to(#e6e6e6));
    background-image: -webkit-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
    background-image: -moz-linear-gradient(top, #ffffff, #ffffff 25%, #e6e6e6);
    background-image: -ms-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
    background-image: -o-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
    background-image: linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
    background-repeat: no-repeat;
    border: 1px solid #ccc;
    border-bottom-color: #bbb;
    .box-shadow(inset 0 1px 0 rgba(255,255,255,.2));

    &:hover, &:focus {
        color: #333;
        text-decoration: none;
        background-position: 0 -10px;
        .gh-icon {
            .opacity(75);
        }
    }
    &:active {
        .box-shadow(inset 0 2px 4px rgba(0,0,0,.15));
    }
}
.gh-ico {
    width: 14px;
    height: 14px;
    margin-right: 4px;
    vertical-align: middle;
    background: url(../images/github-icons.png) no-repeat 0 0;
    .opacity(65);
}
.gh-count {
    display: none; /* hidden to start */
    margin-left: 2px;
    background-color: #fff;
    border: 1px solid #ddd;

    &:hover, &:focus {
        color: #333;
        text-decoration: none;
        background-color: #f5f5f5;
        border-color: #d5d5d5;
    }
}

.github-btn-large {
    height: 30px;

    .gh-btn, .gh-count {
        padding: 3px 10px 3px 8px;
        font-size: 16px;
        line-height: 22px;
        .border-radius(5px);
    }
    .gh-ico {
        width: 22px;
        height: 22px;
        background-position: 0 -20px;
    }
    .gh-count {
        margin-left: 4px;
    }
}