{% extends "sentry/bases/admin.html" %}

{% block admin-nav-packages %} class="active"{% endblock %}

{% load i18n %}
{% load sentry_helpers %}

{% block title %}{% trans "Packages" %} | {{ block.super }}{% endblock %}

{% block inner %}
    <div class="page-header">
        <h2>{% trans "Extensions" %}</h2>
    </div>
    {% if extensions %}
        <table class="table table-bordered table-striped">
            <colgroup>
                <col style="width:220px">
            </colgroup>
            <tbody>
                {% for key, value in extensions %}
                    <tr>
                        <th>{{ key }}</th>
                        <td class="code">{{ value }}</td>
                    </tr>
                {% endfor %}
            </tbody>
        </table>
    {% else %}
        <p>{% trans "No extensions registered." %}</p>
    {% endif %}
    <div class="page-header">
        <h2>{% trans "Modules" %}</h2>
    </div>
    <table class="table table-bordered table-striped">
        <colgroup>
            <col style="width:220px">
        </colgroup>
        <tbody>
            {% for key, value in modules %}
                <tr>
                    <th>{{ key }}</th>
                    <td class="code">{{ value }}</td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
{% endblock %}
