{% load i18n %}

<div class="btn-toolbar">
    <div class="btn-group pull-right">
        <a class="btn prev{% if not paginator.has_previous %} disabled{% endif %}" href="?{{ query_string|escape }}&amp;p={{ paginator.previous_page }}"><span>{% trans "Previous" %}</span></a>
        <a class="btn next{% if not paginator.has_next %} disabled{% endif %}" href="?{{ query_string|escape }}&amp;p={{ paginator.next_page }}"><span>{% trans "Next" %}</span></a>
    </div>
</div>
