{% extends "sentry/partial/client_config/python_base.html" %}

{% load i18n %}

{% block inner %}
	<p>{% trans "Then simply modify your Django configuration:" %}</p>

	<pre># {% trans "Set your DSN value" %}
RAVEN_CONFIG = {
    'dsn': '{% if dsn %}{{ dsn }}{% else %}<strong>SENTRY_DSN</strong>{% endif %}',
}

# {% trans "Add raven to the list of installed apps" %}
INSTALLED_APPS = INSTALLED_APPS + (
    # ...
    'raven.contrib.django.raven_compat',
)</pre>

	<p>{% trans "That's it! Raven automatically installs an error handling hook to pipe all uncaught exceptions to Sentry." %}</p>

	<p>{% trans "If you wish to test your connection to the server, you can use the raven test command:" %}</p>

	<pre>python manage.py raven test</pre>
{% endblock %}
