{% extends "sentry/layout.html" %}

{% load i18n %}

{% block title %}{{ title }} | {{ block.super }}{% endblock %}

{% block page_header %}
    <h2>{{ title }}</h2>
{% endblock %}

{% block content %}
    <section class="body">
        {{ message|linebreaks }}
    </section>
{% endblock %}
