{% extends "sentry/projects/base.html" %}

{% load i18n %}

{% block title %}{% trans "New Project" %} | {{ block.super }}{% endblock %}

{% block main %}
    <section class="body">
        <p>{% trans "You are not able to create a new project because you are not a member of any teams. Ask an administrator to add you to a team." %}</p>
    </section>
{% endblock %}
