{% extends "sentry/teams/groups/list.html" %}

{% load i18n %}

{% block title %}{% trans "New Access Group" %} | {{ block.super }}{% endblock %}

{% block inner %}
    <div class="page-header">
        <h2>{% trans "New Access Group" %}</h2>
    </div>

    {% include "sentry/partial/_form.html" %}
{% endblock %}
