{% load i18n %}
{% load sentry_helpers %}

{% if tags %}
    <div id="tags">
        <div class="page-header">
            <h2>Tags</h2>
        </div>
        <ul class="mini-tag-list">
            {% for tag_key, tag_value in tags %}
                <li>
                    <strong>{{ tag_key }}</strong>
                    <em>=</em>
                    <span><a href="{% url 'sentry-stream' group.team.slug group.project.slug %}?{{ tag_key }}={{ tag_value }}">{{ tag_value }}</a> {% if tag_value|is_url %}<a href="{{ tag_value }}" class="icon-share"></a>{% endif %}</span></li>
            {% endfor %}
        </ul>
    </div>
{% endif %}

{% for interface, interface_html in interface_list %}
    <div id="{{ interface.get_slug }}">
        {{ interface_html }}
    </div>
{% endfor %}

{% if json_data %}
    <div id="extra">
        <div class="page-header">
            <h2>{% trans "Additional Data" %}</h2>
        </div>
        {% if json_data %}
            {% render_values json_data %}
        {% endif %}
    </div>
{% endif %}

{% if version_data %}
    <div id="versions">
        <div class="page-header">
            <h2>{% trans "Package Versions" %}</h2>
        </div>
        <table class="table table-striped">
            <colgroup>
                <col style="width:130px">
            </colgroup>
            {% for k, v in version_data.iteritems|as_sorted %}
                <tr>
                    <th class="key">{{ k }}</th>
                    <td class="values"><code>{{ v }}</code></td>
                </tr>
            {% endfor %}
        </table>
    </div>
{% endif %}
